import { EventEmitter, QueryList, DoCheck } from '@angular/core';
import { ICalendarDate, Calendar, WEEKDAYS, IFormattingOptions } from '../../calendar';
import { ControlValueAccessor } from '@angular/forms';
import { IgxDayItemComponent } from './day-item.component';
import { DateRangeDescriptor } from '../../core/dates';
/**
 * Sets the calender view - days, months or years.
 */
export declare enum CalendarView {
    DEFAULT = 0,
    YEAR = 1,
    DECADE = 2
}
/**
 * Sets the selction type - single, multi or range.
 */
export declare enum CalendarSelection {
    SINGLE = "single",
    MULTI = "multi",
    RANGE = "range"
}
export declare class IgxDaysViewComponent implements ControlValueAccessor, DoCheck {
    /**
     * Sets/gets the `id` of the days view.
     * If not set, the `id` will have value `"igx-days-view-0"`.
     * ```html
     * <igx-days-view id="my-days-view"></igx-days-view>
     * ```
     * ```typescript
     * let daysViewId =  this.daysView.id;
     * ```
     * @memberof IgxDaysViewComponent
     */
    id: string;
    /**
     * Gets the start day of the week.
     * Can return a numeric or an enum representation of the week day.
     * Defaults to `Sunday` / `0`.
     * ```typescript
     * let weekStart =  this.calendar.weekStart;
     * ```
     * @memberof IgxCalendarComponent
     */
    /**
    * Sets the start day of the week.
    * Can be assigned to a numeric value or to `WEEKDAYS` enum value.
    * ```html
    * <igx-calendar [weekStart]="1"></igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    weekStart: WEEKDAYS | number;
    /**
     * Gets the `locale` of the calendar.
     * Default value is `"en"`.
     * ```typescript
     * let locale =  this.calendar.locale;
     * ```
     * @memberof IgxCalendarComponent
     */
    /**
    * Sets the `locale` of the calendar.
    * Expects a valid BCP 47 language tag.
    * Default value is `"en"`.
    * ```html
    * <igx-calendar [locale]="de"></igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    locale: string;
    /**
     *
     * Gets the selection type of the calendar.
     * Default value is `"single"`.
     * Changing the type of selection in the calendar resets the currently
     * selected values if any.
     * ```typescript
     * let selectionType =  this.calendar.selection;
     * ```
     * @memberof IgxCalendarComponent
     */
    /**
    * Sets the selection type of the calendar.
    * ```html
    * <igx-calendar [selection]="'multi'"></igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    selection: string;
    /**
     * Gets the date that is presented in the calendar.
     * By default it is the current date.
     * ```typescript
     * let date = this.calendar.viewDate;
     * ```
     * @memberof IgxCalendarComponent
     */
    /**
    * Sets the date that will be presented in the default view when the calendar renders.
    * ```html
    * <igx-calendar viewDate = "15/06/2018"></igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    viewDate: Date;
    /**
     * Gets the selected date(s) of the calendar.
     *
     * When the calendar selection is set to `single`, it returns
     * a single `Date` object.
     * Otherwise it is an array of `Date` objects.
     * ```typescript
     * let selectedDates =  this.calendar.value;
     * ```
     * @memberof IgxCalendarComponent
     */
    /**
    * Sets the selected date(s) of the calendar.
    *
    * When the calendar selection is set to `single`, it accepts
    * a single `Date` object.
    * Otherwise it is an array of `Date` objects.
    * ```typescript
    *  this.calendar.value =  new Date(`2016-06-12`);
    * ```
    * @memberof IgxCalendarComponent
    */
    value: Date | Date[];
    /**
     * Gets the date format options of the calendar.
     * ```typescript
     * let dateFormatOptions = this.calendar.formatOptions.
     * ```
     */
    /**
    * Sets the date format options of the calendar.
    * ```html
    * <igx-calendar> [formatOptions] = "{ day: '2-digit', month: 'short', weekday: 'long', year: 'numeric' }"</igx-calendar>
    * ```
    * @memberof IgxCalendarComponent
    */
    formatOptions: IFormattingOptions;
    /**
     * Gets the disabled dates descriptors.
     * ```typescript
     * let disabledDates = this.calendar.disabledDates;
     * ```
     */
    /**
    * Sets the disabled dates' descriptors.
    * ```typescript
    *@ViewChild("MyCalendar")
    *public calendar: IgCalendarComponent;
    *ngOnInit(){
    *    this.calendar.disabledDates = [
    *     {type: DateRangeType.Between, dateRange: [new Date("2020-1-1"), new Date("2020-1-15")]},
    *     {type: DateRangeType.Weekends}];
    *}
    *```
    */
    disabledDates: DateRangeDescriptor[];
    /**
     * Gets the special dates descriptors.
     * ```typescript
     * let specialDates = this.calendar.specialDates;
     * ```
     */
    /**
    * Sets the special dates' descriptors.
    * ```typescript
    *@ViewChild("MyCalendar")
    *public calendar: IgCalendarComponent;
    *ngOnInit(){
    *    this.calendar.specialDates = [
    *     {type: DateRangeType.Between, dateRange: [new Date("2020-1-1"), new Date("2020-1-15")]},
    *     {type: DateRangeType.Weekends}];
    *}
    *```
    */
    specialDates: DateRangeDescriptor[];
    /**
     * @hidden
     */
    animationAction: any;
    /**
     * @hidden
     */
    changeDaysView: boolean;
    /**
     * Emits an event when a date is selected.
     * Provides reference the `selectedDates` property.
     * ```html
     * <igx-calendar (onSelection) = "onSelection($event)"></igx-calendar>
     * ```
     * @memberof IgxCalendarComponent
     */
    onSelection: EventEmitter<Date | Date[]>;
    /**
     * @hidden
     */
    onDateSelection: EventEmitter<ICalendarDate>;
    /**
     * @hidden
     */
    onViewChanged: EventEmitter<Date>;
    /**
     * @hidden
     */
    dates: QueryList<IgxDayItemComponent>;
    /**
     *@hidden
     */
    private _viewDate;
    /**
    *@hidden
    */
    private _locale;
    /**
     *@hidden
     */
    private _disabledDates;
    /**
     *@hidden
     */
    private _specialDates;
    /**
     *@hidden
     */
    private _selection;
    /**
     *@hidden
     */
    private rangeStarted;
    /**
     * @hidden
     */
    private _nextDate;
    /**
     * @hidden
     */
    private callback;
    /**
     *@hidden
     */
    protected formatterWeekday: any;
    /**
     *@hidden
     */
    protected formatterMonth: any;
    /**
     *@hidden
     */
    protected formatterMonthday: any;
    /**
     *@hidden
     */
    protected formatterYear: any;
    /**
     *@hidden
     */
    protected formatterDay: any;
    /**
     *@hidden
     */
    calendarModel: Calendar;
    /**
     *@hidden
     */
    _formatOptions: {
        day: string;
        month: string;
        weekday: string;
        year: string;
    };
    /**
     * @hidden
     */
    isKeydownTrigger: boolean;
    /**
     * @hidden
     */
    outOfRangeDates: DateRangeDescriptor[];
    /**
     *@hidden
     */
    selectedDates: any;
    /**
     * The default css class applied to the component.
     *
     * @hidden
     */
    styleClass: boolean;
    /**
     * The default `tabindex` attribute for the component.
     *
     * @hidden
     */
    tabindex: number;
    /**
     * @hidden
     */
    readonly getCalendarMonth: ICalendarDate[][];
    /**
     *@hidden
     */
    protected _onTouchedCallback: () => void;
    /**
     *@hidden
     */
    protected _onChangeCallback: (_: Date) => void;
    /**
     * @hidden
     */
    constructor();
    /**
     * @hidden
     */
    ngDoCheck(): void;
    /**
     * Resets the formatters when locale or formatOptions are changed
     *
     * @hidden
     */
    private initFormatters;
    /**
     *@hidden
     */
    private getDateOnly;
    /**
     *@hidden
     */
    private getDateOnlyInMs;
    /**
     *@hidden
     */
    private generateDateRange;
    /**
     * Performs a single selection.
     * @hidden
     */
    private selectSingle;
    /**
     * Performs a multiple selection
     * @hidden
     */
    private selectMultiple;
    /**
     *@hidden
     */
    private selectRange;
    /**
     * Performs a single deselection.
     * @hidden
     */
    private deselectSingle;
    /**
     * Performs a multiple deselection.
     * @hidden
     */
    private deselectMultiple;
    /**
     * Performs a range deselection.
     * @hidden
     */
    private deselectRange;
    /**
     * @hidden
     */
    private focusPreviousUpDate;
    /**
     * @hidden
     */
    private focusNextDownDate;
    /**
     * @hidden
     */
    private focusPreviousDate;
    /**
     * @hidden
     */
    private focusNextDate;
    /**
     * @hidden
     */
    private disableOutOfRangeDates;
    /**
     * @hidden
     */
    registerOnChange(fn: (v: Date) => void): void;
    /**
     * @hidden
     */
    registerOnTouched(fn: () => void): void;
    /**
     * @hidden
     */
    writeValue(value: Date | Date[]): void;
    /**
     * Checks whether a date is disabled.
     *```typescript
     * this.calendar.isDateDisabled(new Date(`2018-06-12`));
     *```
     * @hidden
     */
    isDateDisabled(date: Date): boolean;
    /**
     * Selects date(s) (based on the selection type).
     *```typescript
     * this.calendar.selectDate(new Date(`2018-06-12`));
     *```
     */
    selectDate(value: Date | Date[]): Date;
    /**
     * Deselects date(s) (based on the selection type).
     *```typescript
     * this.calendar.deselectDate(new Date(`2018-06-12`));
     *````
     */
    deselectDate(value?: Date | Date[]): void;
    /**
     * @hidden
     */
    isCurrentMonth(value: Date): boolean;
    /**
     * @hidden
     */
    isCurrentYear(value: Date): boolean;
    /**
     * @hidden
     */
    selectDateFromClient(value: Date): void;
    /**
     *@hidden
     */
    focusActiveDate(): void;
    /**
     * @hidden
     */
    generateWeekHeader(): string[];
    /**
     * Returns the locale representation of the date in the days view.
     *
     * @hidden
     */
    formattedDate(value: Date): string;
    /**
     * @hidden
     */
    rowTracker(index: any, item: any): string;
    /**
     * @hidden
     */
    dateTracker(index: any, item: any): string;
    /**
     * @hidden
     */
    selectDay(event: any): void;
    /**
     * @hidden
     */
    animationDone(event: any, isLast: boolean): void;
    /**
     * @hidden
     */
    onKeydownArrowUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownArrowDown(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownArrowLeft(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownArrowRight(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownHome(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownEnd(event: KeyboardEvent): void;
}
